@@ -1,3 +1,5 @@
+#![deny(clippy::all)]
+
 mod app;
 mod components;
 mod keys;
@@ -8,13 +10,13 @@ mod ui;
 use crate::{app::App, poll::QueueEvent};
 use crossbeam_channel::{select, unbounded};
 use crossterm::{
-    event::{DisableMouseCapture, EnableMouseCapture},
     terminal::{
         disable_raw_mode, enable_raw_mode, EnterAlternateScreen,
         LeaveAlternateScreen,
     },
     ExecutableCommand, Result,
 };
+use log::error;
 use scopetime::scope_time;
 use simplelog::*;
 use std::{env, fs, fs::File, io};
@@ -23,9 +25,7 @@ use tui::{backend::CrosstermBackend, Terminal};
 fn main() -> Result<()> {
     setup_logging();
     enable_raw_mode()?;
-    io::stdout()
-        .execute(EnterAlternateScreen)?
-        .execute(EnableMouseCapture)?;
+    io::stdout().execute(EnterAlternateScreen)?;
 
     let backend = CrosstermBackend::new(io::stdout());
     let mut terminal = Terminal::new(backend)?;
@@ -37,6 +37,14 @@ fn main() -> Result<()> {
 
     let mut app = App::new(tx_git);
 
+    rayon_core::ThreadPoolBuilder::new()
+        .panic_handler(|e| {
+            error!("thread panic: {:?}", e);
+            panic!(e)
+        })
+        .build_global()
+        .unwrap();
+
     let rx_input = poll::start_polling_thread();
 
     app.update();
@@ -67,9 +75,7 @@ fn main() -> Result<()> {
         }
     }
 
-    io::stdout()
-        .execute(LeaveAlternateScreen)?
-        .execute(DisableMouseCapture)?;
+    io::stdout().execute(LeaveAlternateScreen)?;
     disable_raw_mode()?;
     Ok(())
 }
